/* Snownews - A lightweight console RSS newsreader
 * 
 * Copyright 2003-2004 Oliver Feiler <kiza@kcore.de>
 * http://kiza.kcore.de/software/snownews/
 *
 * dialog.h
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef DIALOG_H
#define DIALOG_H

void UIHelpScreen (void);
void UIDisplayFeedHelp (void);
void UIDisplayItemHelp (void);
void UIAbout (void);
char * UIOneLineEntryField (int x, int y);
void UIChangeBrowser (void);
void UIChangeFeedName (struct feed *cur_ptr);
int UIAddFeed (char * newurl);
void FeedInfo (struct feed * current_feed);
int UIDeleteFeed (char * feedname);
void CategorizeFeed (struct feed * current_feed);
char * DialogGetCategoryFilter (void);
int UIPerFeedFilter (struct feed * current_feed);

#endif
